# SbiRandM Complex Builder

Project for the Subject of Structural Bioinformatics realized by Ruben Molina and Miguel Dieguez.

SbiRandM Complex Builder 2.0.1. This program generates a Protein-DNA or Protein-Protein complex, based on a Fasta Sequence and the pairwise interaction structures of the complex.This version uses a Superimposition-based approach to generate the structure.

Source code is available in https://github.com/RMolina93/SbiRandM

Documentation and examples can be found in https://crowthebio.gitbook.io/complex-builder 
